package org.geant.idpextension.oidc.profile.logic;

import java.util.function.Function;
import java.util.function.Predicate;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;

import org.opensaml.profile.context.ProfileRequestContext;
import com.nimbusds.openid.connect.sdk.SubjectType;

import net.shibboleth.utilities.java.support.logic.Constraint;

/** Activation condition returning true if public subject is requested. */
public class PublicSubjectActivationCondition implements Predicate<ProfileRequestContext> {
    
    /** Strategy used to obtain subject type. */
    @Nonnull private Function<ProfileRequestContext,SubjectType> subjectTypeLookupStrategy;
    

    /**
     * Constructor.
     */
    public PublicSubjectActivationCondition() {
        subjectTypeLookupStrategy = new DefaultSubjectTypeStrategy();
    }

    /**
     * Get the strategy used to locate subject type.
     * 
     * @return lookup strategy
     */
    @Nonnull public Function<ProfileRequestContext,SubjectType> getSubjectTypeLookupStrategy() {
        return subjectTypeLookupStrategy;
    }
    
    /**
     * Set the strategy used to locate subject type.
     * 
     * @param strategy lookup strategy
     */
    public void setSubjectTypeLookupStrategy(@Nonnull final Function<ProfileRequestContext, SubjectType> strategy) {
        subjectTypeLookupStrategy =
                Constraint.isNotNull(strategy, "SubjectTypeLookupStrategy lookup strategy cannot be null");
    }
    
    /** {@inheritDoc} */
    public boolean test(@Nullable final ProfileRequestContext input) {
        return SubjectType.PUBLIC.equals(subjectTypeLookupStrategy.apply(input));
    }
    
}